#include <sys/types.h>
#include <musepack/musepack.h>

int main (int argc, char **argv) {
    return 0;
}
